//
//  YHServiceListViewController.swift
//  galaxy
//
//  Created by EDY on 2024/4/8.
//  Copyright © 2024 https://www.galaxy-immi.com. All rights reserved.
//

import UIKit
import JXSegmentedView

class YHServiceListViewController: YHBaseViewController {

    private let serviceCenterMainReqVM : YHServiceCenterMainViewModel = YHServiceCenterMainViewModel()
    let homeViewModel: YHHomePageViewModel = YHHomePageViewModel()
    
    var orderListView: YHOrderListView!
    var normalView: YHServerNoOrderView!
    
    override func viewDidLoad() {
        super.viewDidLoad()
        setupUI()
        handleRightUI()
    }
    
    override func viewWillAppear(_ animated: Bool) {
        super.viewWillAppear(animated)
        handleRightUI()
        loadData()
    }
}

extension YHServiceListViewController {
    func loadData() {
        
        homeViewModel.getHomeBanner(1){[weak self] success, error in
            guard let self = self else { return }
            self.normalView.tableHeadView.bannarView.dataArr = self.homeViewModel.banners ?? []
        }
        
        homeViewModel.getHomeClassify{[weak self] success, error in
            guard let self = self, let classify = self.homeViewModel.classify  else { return }
            for item in classify {
                let model = item as YHHomeClassifyModel
                if model.id == 1 {
                    self.normalView.sectionView.items = model.children
                    let classifyID = model.children.first?.id ?? 0
                    self.homeViewModel.getList(classifyID) {[weak self] success, error in
                        guard let self = self else { return }
                        self.normalView.dataSouce = self.homeViewModel.arrHomeNewsData ?? []
                    }
                }
            }
        }
        
        
        if YHLoginManager.shared.isLogin() == false {
            self.handleRightUI()
            return
        }
        
        serviceCenterMainReqVM.getContactList { success, error in
            if success == true {
                
            } else {
                YHHUD.flash(message: error?.errorMsg ?? "请求出错")
            }
            self.handleRightUI()
        }
    }
    
    func setupUI() {
        gk_navBarAlpha = 0
        gk_navigationBar.isHidden = true
        
        orderListView = {
            let view = YHOrderListView()
            return view
        }()
        view.addSubview(orderListView)
        orderListView.snp.makeConstraints { make in
            make.top.left.right.equalToSuperview()
            make.bottom.equalToSuperview().offset(-k_Height_TabBar)
        }
        
        normalView = {
            let view = YHServerNoOrderView()
            view.sectionBlock = {[weak self] model in
                guard let self = self else { return }
                self.homeViewModel.getList(model.id) {[weak self] success, error in
                    guard let self = self else { return }
                    self.normalView.dataSouce = self.homeViewModel.arrHomeNewsData ?? []
                }
            }
            return view
        }()
        view.addSubview(normalView)
        normalView.snp.makeConstraints { make in
            make.top.left.right.equalToSuperview()
            make.bottom.equalToSuperview().offset(-k_Height_TabBar)
        }
        
    }
}

extension YHServiceListViewController {
    private func handleRightUI() {
        if YHLoginManager.shared.isLogin() == false {
            normalView.isHidden = false
            orderListView.isHidden = true
        } else {
            if serviceCenterMainReqVM.arrContactList.isEmpty {
                normalView.isHidden = false
                orderListView.isHidden = true
            } else {
                normalView.isHidden = true
                orderListView.isHidden = false
                orderListView.dataSource = serviceCenterMainReqVM.arrContactList
            }
        }
    }
}

extension YHServiceListViewController: JXSegmentedListContainerViewListDelegate {
    func listView() -> UIView {
        return view
    }
    
    func listWillAppear() {
        loadData()
    }
}
