//
//  YHHomeCollectionViewCell.swift
//  galaxy
//
//  Created by EDY on 2024/4/8.
//  Copyright © 2024 https://www.galaxy-immi.com. All rights reserved.
//

import UIKit
import Kingfisher

class YHHomeCollectionViewCell: UICollectionViewCell {
    static let cellReuseIdentifier = "YHHomeCollectionViewCell"
    
    
    lazy var viewModel: YHHomeWebViewModel = {
        let viewModel = YHHomeWebViewModel()
        return viewModel
    }()
    
    
    var listModel: YHHomeListModel? {
        didSet {
            updataSubViews()
        }
    }
    
    lazy var titleImageView:UIImageView = {
        let imageV = UIImageView(image: UIImage(named: "home_title_image"))
        imageV.contentMode = .scaleAspectFill
        return imageV
    }()
    
    
    lazy var descripeLable:UILabel = {
        let label = UILabel()
        label.text = "赴港攻略，当日往返无忧，这个季节风景..赴港攻略，当日往返无忧，这个季节风景"
        label.textColor = UIColor(hexString:"#333333")
        label.font = UIFont.PFSC_R(ofSize: 14)
        label.numberOfLines = 2
        label.lineBreakMode = .byWordWrapping
        return label
    }()
    
    
    lazy var headImageView:UIImageView = {
        let imageV = UIImageView(image: UIImage(named: ""))
        imageV.contentMode = .scaleAspectFill
        return imageV
    }()
    
    lazy var heartImageViewBtn : UIButton = {
        let btn : UIButton = UIButton(type: .custom)
        btn.setImage(UIImage(named: "home_grey_heart"), for: .normal)
        btn.setImage(UIImage(named: "home_red_heart"), for: .selected)
        return btn
    }()
    
    lazy var numLable:UILabel = {
        let label = UILabel()
        label.text = ""
        label.textColor = UIColor(hex: 0x121A264D, alpha: 0.3)
        label.font = UIFont.PFSC_R(ofSize: 12)
        return label
    }()
    
    required init?(coder: NSCoder) {
        super.init(coder: coder)
    }
    
    override init(frame: CGRect) {
        super.init(frame: frame)
        setupUI()
    }
    
    private func setupUI() {
        contentView.clipsToBounds = true
        contentView.addSubview(titleImageView)
        titleImageView.snp.makeConstraints { make in
            make.left.right.top.equalToSuperview()
            make.height.equalTo(210)
        }
        
        
        let subHoldView = UIView()
        subHoldView.layer.backgroundColor = UIColor.white.cgColor
        subHoldView.layer.borderWidth = 0.6
        subHoldView.layer.borderColor = UIColor(red: 0.943, green: 0.952, blue: 0.969, alpha: 1).cgColor
        contentView.addSubview(subHoldView)
        subHoldView.snp.makeConstraints { make in
            make.top.equalTo(titleImageView.snp.bottom)
            make.bottom.left.right.equalToSuperview()
        }
        
        subHoldView.addSubview(descripeLable)
        descripeLable.snp.makeConstraints { make in
            make.top.equalToSuperview().offset(10)
            make.left.equalToSuperview().offset(8)
            make.right.equalToSuperview().offset(-8)
        }
        
        subHoldView.addSubview(numLable)
        numLable.snp.makeConstraints { make in
            make.right.equalToSuperview().offset(-8)
            make.top.equalTo(descripeLable.snp.bottom).offset(10)
            make.height.equalTo(16)
        }
        
        subHoldView.addSubview(heartImageViewBtn)
        heartImageViewBtn.snp.makeConstraints { make in
            make.right.equalTo(numLable.snp.left).offset(-2)
            make.height.width.equalTo(16)
            make.centerY.equalTo(numLable)
        }
        
        heartImageViewBtn.addTarget(self, action: #selector(clickHeart), for: .touchUpInside)
        heartImageViewBtn.YH_clickEdgeInsets = UIEdgeInsets(top: 15, left: 15, bottom: 15, right: 15)
    }
    
    func updataSubViews() {
        guard let listModel = listModel else { return }
        titleImageView.snp.remakeConstraints { make in
            make.left.right.top.equalToSuperview()
            make.height.equalTo(listModel.img_height_use)
        }
        if let url = URL(string: listModel.img_url) {
            titleImageView.kf.setImage(with: url)
        }
        descripeLable.text = listModel.title.defaultStringIfEmpty(detaultValue: "***")
        descripeLable.snp.removeConstraints()
        descripeLable.snp.remakeConstraints { make in
            make.top.equalToSuperview().offset(10)
            make.left.equalToSuperview().offset(8)
            make.right.equalToSuperview().offset(-8)
            make.height.equalTo(listModel.textH)
            make.bottom.equalTo(-36)
        }
        numLable.text = listModel.collect_count.string
        heartImageViewBtn.isSelected = listModel.is_like
    }
    
    @objc func clickHeart() {
        guard let listModel = listModel else { return }
        
        if YHLoginManager.shared.isLogin() {
            if listModel.is_like == false {
                viewModel.getLike(listModel.id, 1) {[weak self] success, error in
                    guard let self = self else { return }
                    if success {
                        YHHUD.flash(message: "已点赞")
                        listModel.is_like = true
                        updataSubViews()
                    }
                }
            } else {
                viewModel.getLike(listModel.id, 0) {[weak self] success, error in
                    guard let self = self else { return }
                    if success {
                        YHHUD.flash(message: "已取消点赞")
                        listModel.is_like = false
                        updataSubViews()
                    }
                }
            }
            
            NotificationCenter.default.post(name:YhConstant.YhNotification.refreshHomePageNotifiction, object: nil)
        } else {
            let vc = UINavigationController(rootVC: YHPhoneLoginViewController())
            vc.modalPresentationStyle = .custom
            self.parentViewController?.navigationController?.present(vc, animated: true)
        }
    }
}
